@@ -27,30 +27,52 @@
 
 #include <KLocalizedString>
 
-GroupEntry::GroupEntry(const QString &name, const QString &icon,
-    AbstractModel *model, AbstractModel *parentModel)
+GroupEntry::GroupEntry(RootModel *parentModel, const QString &name,
+    const QString &iconName, AbstractModel *childModel)
+: AbstractGroupEntry(parentModel)
+, m_name(name)
+, m_iconName(iconName)
+, m_childModel(childModel)
 {
-    m_name = name;
-    m_icon = QIcon::fromTheme(icon, QIcon::fromTheme("unknown"));
-    m_model = model;
-    QObject::connect(parentModel, SIGNAL(refreshing()), m_model, SLOT(deleteLater()));
+    QObject::connect(parentModel, &RootModel::cleared, childModel, &AbstractModel::deleteLater);
+
+    QObject::connect(childModel, &AbstractModel::countChanged,
+        [parentModel, this] { if (parentModel) { parentModel->entryChanged(this); } }
+    );
+}
+
+QString GroupEntry::name() const
+{
+    return m_name;
+}
+
+QIcon GroupEntry::icon() const
+{
+    return QIcon::fromTheme(m_iconName, QIcon::fromTheme("unknown"));
+}
+
+bool GroupEntry::hasChildren() const
+{
+    return m_childModel && m_childModel->count() > 0;
+}
+
+AbstractModel *GroupEntry::childModel() const
+{
+    return m_childModel;
 }
 
 RootModel::RootModel(QObject *parent) : AppsModel(QString(), parent)
+, m_favorites(new FavoritesModel(this))
+, m_systemModel(nullptr)
+, m_showAllSubtree(false)
 , m_showRecentApps(true)
 , m_showRecentDocs(true)
 , m_showRecentContacts(false)
 , m_recentAppsModel(0)
 , m_recentDocsModel(0)
 , m_recentContactsModel(0)
+, m_appletInterface(0)
 {
-    FavoritesModel *favoritesModel = new FavoritesModel(this);
-    m_favoritesModels["app"] = favoritesModel;
-
-    favoritesModel = new FavoritesModel(this);
-    m_favoritesModels["sys"] = favoritesModel;
-
-    extendEntryList();
 }
 
 RootModel::~RootModel()
@@ -68,7 +90,7 @@ QVariant RootModel::data(const QModelIndex& index, int role) const
 
         if (entry->type() == AbstractEntry::GroupType) {
             const GroupEntry *group = static_cast<const GroupEntry *>(entry);
-            AbstractModel *model = group->model();
+            AbstractModel *model = group->childModel();
 
             if (model == m_recentAppsModel
                 || model == m_recentDocsModel
@@ -76,8 +98,12 @@ QVariant RootModel::data(const QModelIndex& index, int role) const
                 if (role ==  Kicker::HasActionListRole) {
                     return true;
                 } else if (role == Kicker::ActionListRole) {
-                    return QVariantList() << Kicker::createActionItem(i18n("Hide %1",
+                    QVariantList actionList;
+                    actionList << model->actions();
+                    actionList << Kicker::createSeparatorActionItem();
+                    actionList << Kicker::createActionItem(i18n("Hide %1",
                         group->name()), "hideCategory");
+                    return actionList;
                 }
             }
         }
@@ -88,12 +114,11 @@ QVariant RootModel::data(const QModelIndex& index, int role) const
 
 bool RootModel::trigger(int row, const QString& actionId, const QVariant& argument)
 {
-    if (actionId == "hideCategory") {
-        const AbstractEntry *entry = m_entryList.at(row);
+    const AbstractEntry *entry = m_entryList.at(row);
 
-        if (entry->type() == AbstractEntry::GroupType) {
-            const GroupEntry *group = static_cast<const GroupEntry *>(entry);
-            AbstractModel *model = group->model();
+    if (entry->type() == AbstractEntry::GroupType) {
+        if (actionId == "hideCategory") {
+            AbstractModel *model = entry->childModel();
 
             if (model == m_recentAppsModel) {
                 setShowRecentApps(false);
@@ -108,6 +133,8 @@ bool RootModel::trigger(int row, const QString& actionId, const QVariant& argume
 
                 return true;
             }
+        } else if (entry->childModel()->hasActions()) {
+            return entry->childModel()->trigger(-1, actionId, QVariant());
         }
     }
 
@@ -130,6 +157,22 @@ void RootModel::setShowRecentApps(bool show)
     }
 }
 
+bool RootModel::showAllSubtree() const
+{
+    return m_showAllSubtree;
+}
+
+void RootModel::setShowAllSubtree(bool show)
+{
+    if (m_showAllSubtree != show) {
+        m_showAllSubtree = show;
+
+        refresh();
+
+        emit showAllSubtreeChanged();
+    }
+}
+
 bool RootModel::showRecentDocs() const
 {
     return m_showRecentDocs;
@@ -162,100 +205,122 @@ void RootModel::setShowRecentContacts(bool show)
     }
 }
 
-QObject *RootModel::favoritesModelForPrefix(const QString &prefix)
+QObject* RootModel::appletInterface() const
 {
-    return m_favoritesModels.value(prefix);
+    return m_appletInterface;
+}
+
+void RootModel::setAppletInterface(QObject* appletInterface)
+{
+    if (m_appletInterface != appletInterface) {
+        m_appletInterface = appletInterface;
+
+        refresh();
+
+        emit appletInterfaceChanged();
+    }
+}
+
+AbstractModel* RootModel::favoritesModel()
+{
+    return m_favorites;
+}
+
+AbstractModel* RootModel::systemFavoritesModel()
+{
+    if (m_systemModel) {
+        return m_systemModel->favoritesModel();
+    }
+
+    return nullptr;
 }
 
 void RootModel::refresh()
 {
-    AppsModel::refresh();
-    extendEntryList();
+    if (!m_appletInterface) {
+        return;
+    }
 
-    m_favoritesModels["app"]->refresh();
+    beginResetModel();
+
+    AppsModel::refreshInternal();
+
+    AppsModel *allModel = nullptr;
+    m_recentAppsModel = nullptr;
+    m_recentDocsModel = nullptr;
+    m_recentContactsModel = nullptr;
+
+    if (m_showAllSubtree) {
+        QHash<QString, QList<AbstractEntry *>> m_categoryHash;
+
+        foreach (const AbstractEntry *groupEntry, m_entryList) {
+            AbstractModel *model = groupEntry->childModel();
+
+            for (int i = 0; i < model->count(); ++i) {
+                AbstractEntry *appEntry = static_cast<AbstractEntry *>(model->index(i, 0).internalPointer());
+
+                if (appEntry->name().isEmpty()) {
+                    continue;
+                }
+
+                const QChar &first = appEntry->name().at(0).toUpper();
+                m_categoryHash[first.isDigit() ? QStringLiteral("0-9") : first].append(appEntry);
+            }
+        }
+
+        QList<AbstractEntry *> groups;
+        QHashIterator<QString, QList<AbstractEntry *>> i(m_categoryHash);
+
+        while (i.hasNext()) {
+            i.next();
+            AppsModel *model = new AppsModel(i.value(), false, this);
+            model->setDescription(i.key());
+            groups.append(new GroupEntry(this, i.key(), QString(), model));
+        }
+
+        allModel = new AppsModel(groups, true, this);
+        allModel->setDescription(QStringLiteral("KICKER_ALL_MODEL")); // Intentionally no i18n.
+    }
+
+    if (m_showSeparators) {
+        m_entryList.prepend(new SeparatorEntry(this));
+        ++m_separatorCount;
+    }
+
+    if (allModel) {
+        m_entryList.prepend(new GroupEntry(this, i18n("All Applications"), QString(), allModel));
+    }
+
+    if (m_showRecentContacts) {
+        m_recentContactsModel = new RecentContactsModel(this);
+        m_entryList.prepend(new GroupEntry(this, i18n("Recent Contacts"), QString(), m_recentContactsModel));
+    }
+
+    if (m_showRecentDocs) {
+        m_recentDocsModel = new RecentDocsModel(this);
+        m_entryList.prepend(new GroupEntry(this, i18n("Recent Documents"), QString(), m_recentDocsModel));
+    }
+
+    if (m_showRecentApps) {
+        m_recentAppsModel = new RecentAppsModel(this);
+        m_entryList.prepend(new GroupEntry(this, i18n("Recent Applications"), QString(), m_recentAppsModel));
+    }
+
+    m_systemModel = new SystemModel(this);
+    m_entryList << new GroupEntry(this, i18n("Power / Session"), QString(), m_systemModel);
+
+    endResetModel();
+
+    m_favorites->refresh();
+
+    emit systemFavoritesModelChanged();
+    emit countChanged();
+    emit separatorCountChanged();
+
+    emit refreshed();
 }
 
 void RootModel::extendEntryList()
 {
-    m_recentAppsModel = 0;
 
-    if (m_showRecentApps) {
-        m_recentAppsModel = new RecentAppsModel(this);
-        connect(m_recentAppsModel, SIGNAL(countChanged()), this, SLOT(childModelChanged()));
-    }
-
-    m_recentDocsModel = 0;
-
-    if (m_showRecentDocs) {
-        m_recentDocsModel = new RecentDocsModel(this);
-        connect(m_recentDocsModel, SIGNAL(countChanged()), this, SLOT(childModelChanged()));
-    }
-
-    m_recentContactsModel = 0;
-
-    if (m_showRecentContacts) {
-        m_recentContactsModel = new RecentContactsModel(this);
-        connect(m_recentContactsModel, SIGNAL(countChanged()), this, SLOT(childModelChanged()));
-    }
-
-    SystemModel *systemModel = new SystemModel(this);
-    m_favoritesModels["sys"]->setSourceModel(systemModel);
-
-    int insertCount = 0;
-    if (m_recentAppsModel) ++insertCount;
-    if (m_recentDocsModel) ++insertCount;
-    if (m_recentContactsModel) ++insertCount;
-
-    if (insertCount) {
-        beginInsertRows(QModelIndex(), 0, insertCount);
-
-        GroupEntry *entry = 0;
-
-        m_entryList.prepend(new DividerEntry());
-
-        if (m_recentContactsModel) {
-            entry = new GroupEntry(i18n("Recent Contacts"), QString(), m_recentContactsModel, this);
-            m_entryList.prepend(entry);
-        }
-
-        if (m_recentDocsModel) {
-            entry = new GroupEntry(i18n("Recent Documents"), QString(), m_recentDocsModel, this);
-            m_entryList.prepend(entry);
-        }
-
-        if (m_recentAppsModel) {
-            entry = new GroupEntry(i18n("Recent Applications"), QString(), m_recentAppsModel, this);
-            m_entryList.prepend(entry);
-        }
-
-        endInsertRows();
-    }
-
-    beginInsertRows(QModelIndex(), m_entryList.size(), m_entryList.size());
-    m_entryList << new GroupEntry(i18n("Power / Session"), QString(), systemModel, this);
-    endInsertRows();
-
-    emit countChanged();
-}
-
-void RootModel::childModelChanged()
-{
-    QObject *model = sender();
-
-    for (int i = 0; i < m_entryList.size(); ++i) {
-        const AbstractEntry *entry = m_entryList.at(i);
-
-        if (entry->type() == AbstractEntry::GroupType) {
-            const GroupEntry *group = static_cast<const GroupEntry *>(entry);
-
-            if (group->model() == model) {
-                const QModelIndex &idx = index(i, 0);
-
-                emit dataChanged(idx, idx);
-
-                break;
-            }
-        }
-
-    }
 }
