@@ -35,15 +35,12 @@
 #include <QLCDNumber>
 #include <QPushButton>
 #include <QRadioButton>
+#include <QX11Info>
 
 #include <kapplication.h>
 
 
 #include <config-workspace.h>
-#include <config-kcontrol-input.h>
-#ifdef HAVE_LIBUSB
-#include "logitechmouse.h"
-#endif
 
 #include <kcmodule.h>
 #include "ui_kmousedlg.h"
@@ -68,7 +65,7 @@ class MouseSettings
 {
 public:
   void save(KConfig *);
-  void load(KConfig *);
+  void load(KConfig *, Display *dpy = QX11Info::display());
   void apply(bool force=false);
 public:
  int num_buttons;
@@ -87,10 +84,6 @@ public:
  int wheelScrollLines;
  bool reverseScrollPolarity;
 
- #ifdef HAVE_LIBUSB
- // TODO: In Qt4, replace with a better container.
- QList <LogitechMouse*> logitechMouseList;
- #endif
 };
 
 class MouseConfig : public KCModule
