@@ -29,11 +29,12 @@
 #include "bindings.h"
 
 
-class KActionCollection;
+Q_DECLARE_LOGGING_CATEGORY(KCM_KEYBOARD)
+
+
 class XInputEventNotifier;
 class LayoutTrayIcon;
 class KeyboardConfig;
-class KAction;
 class Rules;
 
 class Q_DECL_EXPORT KeyboardDaemon : public KDEDModule
